PyBaccarat: pybaccarat.baccarat.Game Class Reference

PyBaccarat visit the ministry of silly walks

Public Member Functions | Public Attributes | List of all members
pybaccarat.baccarat.Game Class Reference

This class plays a game of Baccarat. More...

Inheritance diagram for pybaccarat.baccarat.Game:

## Public Member Functions
def | __init__ (self, the_shoe, the_player, the_banker, the_system=None)
| TBD.
def | play_hand (self)
| play a single hand zparam hand_number int More...
def | side_count (self, hand, rc1, rc2)
def | play (self, display=True, show_burn_cards=False, interactive=False)
| TBD.
def | __init__ (self, the_shoe, the_player, the_banker, the_system=None)
| TBD.
def | play_hand (self)
| play a single hand zparam hand_number int More...
def | side_count (self, hand, rc1, rc2)
def | play (self, display=True, show_burn_cards=False, interactive=False)
| TBD.

## Public Attributes
| system_play
| !< system_play is the bacc system we are tracking
| count_d7
| count_p8

## Detailed Description

This class plays a game of Baccarat.

## Member Function Documentation

## ◆ play_hand() [1/2]

def pybaccarat.baccarat.Game.play_hand | ( |  | self | ) |

play a single hand zparam hand_number int

Returns
  (win,diff)

## ◆ play_hand() [2/2]

def pybaccarat.baccarat.Game.play_hand | ( |  | self | ) |

play a single hand zparam hand_number int

Returns
  (win,diff)

The documentation for this class was generated from the following file:

- build/lib/pybaccarat/baccarat.py